View source: R/utils_parse-questions.R
| listUniqueQuestions | R Documentation |
Convert dataframe of questions to list for use in Shiny UI
listUniqueQuestions(df)
df |
A user supplied dataframe in the format of teaching_r_questions. |
A list of unique questions for each UI element
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.